==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/zh-TW/localizations.php <==
<?php

return [

    'select_language' => '選擇語言',
    'languages' => [
        'en-US'=> '美式英語',
        'en-GB'=> '英式英語',
        'am-ET' => 'Amharic',
        'af-ZA'=> '南非荷蘭語',
        'ar-SA'=> '阿拉伯語',
        'bg-BG'=> '保加利亞語',
        'zh-CN'=> '簡體中文',
        'zh-TW'=> '繁體中文',
        'ca-ES' => 'Catalan',
        'hr-HR'=> '克羅埃西亞語',
        'cs-CZ'=> '捷克語',
        'da-DK'=> '丹麥語',
        'nl-NL'=> '荷蘭語',
        'en-ID'=> '印度尼西亞英語',
        'et-EE'=> '愛沙尼亞語',
        'fil-PH'=> '菲律賓語',
        'fi-FI'=> '芬蘭語',
        'fr-FR'=> '法語',
        'de-DE'=> '德語',
        'de-if'=> '德語（非正式）',
        'el-GR'=> '希臘語',
        'he-IL'=> '希伯來語',
        'hu-HU'=> '匈牙利語',
        'is-IS' => '冰島語',
        'id-ID'=> '印尼語',
        'ga-IE'=> '愛爾蘭語',
        'it-IT'=> '義大利語',
        'ja-JP'=> '日語',
        'km-KH'=>'Khmer',
        'ko-KR'=> '韓語',
        'lt-LT'=>'立陶宛語',
        'lv-LV'=> '拉脫維亞語',
        'mk-MK'=> '馬其頓語',
        'ms-MY'=> '馬來語',
        'mi-NZ'=> '毛利語',
        'mn-MN'=> '蒙古語',
        'no-NO'=> '挪威語',
        'fa-IR'=> '波斯語',
        'pl-PL'=> '波蘭語',
        'pt-PT'=> '葡萄牙語',
        'pt-BR'=> '巴西葡萄牙語',
        'ro-RO'=> '羅馬尼亞語',
        'ru-RU'=> '俄語',
        'sr-CS' => '塞爾維亞語（拉丁文）',
        'sk-SK'=> 'Slovak',
        'sl-SI'=> '斯洛維尼亞語',
        'es-ES'=> '西班牙語',
        'es-CO'=> '哥倫比亞西班牙語',
        'es-MX'=> '墨西哥西班牙語',
        'es-VE'=> '委內瑞拉西班牙語',
        'sv-SE'=> '瑞典語',
        'tl-PH'=> '塔加洛語',
        'ta-IN'=> '泰米爾語',
        'th-TH'=> '泰語',
        'tr-TR'=> '土耳其語',
        'uk-UA'=> '烏克蘭語',
        'vi-VN'=> '越南語',
        'cy-GB'=> '威爾斯語',
        'zu-ZA'=> '祖魯語',
    ],

    'select_country' => '選擇一個國家',
    
    'countries' => [
        'AC'=>'阿森松島',
        'AD'=>'安道爾',
        'AE'=>'阿拉伯聯合大公國',
        'AF'=>'阿富汗',
        'AG'=>'安提瓜和巴布達',
        'AI'=>'安圭拉',
        'AL'=>'阿爾巴尼亞',
        'AM'=>'亞美尼亞',
        'AN'=>'荷屬安的列斯',
        'AO'=>'安哥拉',
        'AQ'=>'南極洲',
        'AR'=>'阿根廷',
        'AS'=>'美屬薩摩亞',
        'AT'=>'奧地利',
        'AU'=>'澳洲',
        'AW'=>'阿魯巴',
        'AX'=>'奧蘭群島',
        'AZ'=>'亞塞拜然',
        'BA'=>'波士尼亞和赫塞哥維納',
        'BB'=>'巴貝多',
        'BE'=>'比利時',
        'BD'=>'孟加拉',
        'BF'=>'布吉納法索',
        'BG'=>'保加利亞',
        'BH'=>'巴林',
        'BI'=>'蒲隆地',
        'BJ'=>'貝南',
        'BM'=>'百慕達',
        'BN'=>'汶萊',
        'BO'=>'玻利維亞',
        'BR'=>'巴西',
        'BS'=>'巴哈馬',
        'BT'=>'不丹',
        'BV'=>'布韋島',
        'BW'=>'波札那',
        'BY'=>'白俄羅斯',
        'BZ'=>'貝里斯',
        'CA'=>'加拿大',
        'CC'=>'科科斯（基林）群島',
        'CD'=>'剛果（金夏沙）',
        'CF'=>'中非共和國',
        'CG'=>'剛果（布拉薩）',
        'CH'=>'瑞士',
        'CI'=>'象牙海岸',
        'CK'=>'庫克群島',
        'CL'=>'智利',
        'CM'=>'喀麥隆',
        'CN'=>'中華人民共和國',
        'CO'=>'哥倫比亞',
        'CR'=>'哥斯大黎加',
        'CU'=>'古巴',
        'CV'=>'維德角',
        'CX'=>'聖誕島',
        'CY'=>'賽普勒斯',
        'CZ'=>'捷克',
        'DE'=>'德國',
        'DJ'=>'吉布地',
        'DK'=>'丹麥',
        'DM'=>'多米尼克',
        'DO'=>'多明尼加共和國',
        'DZ'=>'阿爾及利亞',
        'EC'=>'厄瓜多',
        'EE'=>'愛沙尼亞',
        'EG'=>'埃及',
        'ER'=>'厄利垂亞',
        'ES'=>'西班牙',
        'ET'=>'衣索比亞',
        'EU'=>'歐洲聯盟',
        'FI'=>'芬蘭',
        'FJ'=>'斐濟',
        'FK'=>'福克蘭群島',
        'FM'=>'密克羅尼西亞聯邦',
        'FO'=>'法羅群島',
        'FR'=>'法國',
        'GA'=>'加彭',
        'GD'=>'格瑞那達',
        'GE'=>'喬治亞',
        'GF'=>'法屬圭亞那',
        'GG'=>'根西島',
        'GH'=>'迦納',
        'GI'=>'直布羅陀',
        'GL'=>'格陵蘭',
        'GM'=>'甘比亞',
        'GN'=>'幾內亞',
        'GP'=>'瓜地洛普',
        'GQ'=>'赤道幾內亞',
        'GR'=>'希臘',
        'GS'=>'南喬治亞與南桑威奇群島',
        'GT'=>'瓜地馬拉',
        'GU'=>'關島',
        'GW'=>'幾內亞比索',
        'GY'=>'蓋亞那',
        'HK'=>'香港',
        'HM'=>'赫德島和麥當勞群島',
        'HN'=>'洪都拉斯',
        'HR'=>'克羅埃西亞',
        'HT'=>'海地',
        'HU'=>'匈牙利',
        'ID'=>'印尼',
        'IE'=>'愛爾蘭',
        'IL'=>'以色列',
        'IM'=>'曼島',
        'IN'=>'印度',
        'IO'=>'英屬印度洋領地',
        'IQ'=>'伊拉克',
        'IR'=>'伊朗',
        'IS'=>'冰島',
        'IT'=>'義大利',
        'JE'=>'澤西島',
        'JM'=>'牙買加',
        'JO'=>'約旦',
        'JP'=>'日本',
        'KE'=>'肯亞',
        'KG'=>'吉爾吉斯',
        'KH'=>'柬埔寨',
        'KI'=>'吉里巴斯',
        'KM'=>'葛摩',
        'KN'=>'聖克里斯多福和尼維斯',
        'KR'=>'南韓',
        'KW'=>'科威特',
        'KY'=>'開曼群島',
        'KZ'=>'哈薩克',
        'LA'=>'寮國',
        'LB'=>'黎巴嫩',
        'LC'=>'聖露西亞',
        'LI'=>'列支敦斯登',
        'LK'=>'斯里蘭卡',
        'LR'=>'賴比瑞亞',
        'LS'=>'賴索托',
        'LT'=>'立陶宛',
        'LU'=>'盧森堡',
        'LV'=>'拉脫維亞',
        'LY'=>'利比亞',
        'MA'=>'摩洛哥',
        'MC'=>'摩納哥',
        'MD'=>'摩爾多瓦',
        'ME'=>'蒙特內哥羅',
        'MG'=>'馬達加斯加',
        'MH'=>'馬紹爾群島',
        'MK'=>'馬其頓',
        'ML'=>'馬利',
        'MM'=>'緬甸',
        'MN'=>'蒙古',
        'MO'=>'澳門',
        'MP'=>'北馬里亞納群島',
        'MQ'=>'馬丁尼克',
        'MR'=>'茅利塔尼亞',
        'MS'=>'蒙特塞拉特',
        'MT'=>'馬爾他',
        'MU'=>'模里西斯',
        'MV'=>'馬爾地夫',
        'MW'=>'馬拉威',
        'MX'=>'墨西哥',
        'MY'=>'馬來西亞',
        'MZ'=>'莫三比克',
        'NA'=>'納米比亞',
        'NC'=>'新喀里多尼亞',
        'NE'=>'尼日',
        'NF'=>'諾福克島',
        'NG'=>'奈及利亞',
        'NI'=>'尼加拉瓜',
        'NL'=>'荷蘭',
        'NO'=>'挪威',
        'NP'=>'尼泊爾',
        'NR'=>'諾魯',
        'NU'=>'紐埃',
        'NZ'=>'紐西蘭',
        'OM'=>'阿曼',
        'PA'=>'巴拿馬',
        'PE'=>'秘魯',
        'PF'=>'法屬玻里尼西亞',
        'PG'=>'巴布亞紐幾內亞',
        'PH'=>'菲律賓',
        'PK'=>'巴基斯坦',
        'PL'=>'波蘭',
        'PM'=>'聖皮耶與密克隆',
        'PN'=>'皮特肯群島',
        'PR'=>'波多黎各',
        'PS'=>'巴勒斯坦',
        'PT'=>'葡萄牙',
        'PW'=>'帛琉',
        'PY'=>'巴拉圭',
        'QA'=>'卡達',
        'RE'=>'留尼旺',
        'RO'=>'羅馬尼亞',
        'RS'=>'塞爾維亞',
        'RU'=>'俄羅斯',
        'RW'=>'盧安達',
        'SA'=>'沙烏地阿拉伯',
        'UK'=>'英國',
        'SB'=>'索羅門群島',
        'SC'=>'塞席爾',
        'SS'=>'南蘇丹',
        'SD'=>'蘇丹',
        'SE'=>'瑞典',
        'SG'=>'新加坡',
        'SH'=>'聖赫勒拿島',
        'SI'=>'斯洛維尼亞',
        'SJ'=>'斯瓦爾巴特和揚馬延島',
        'SK'=>'斯洛伐克',
        'SL'=>'獅子山',
        'SM'=>'聖馬利諾',
        'SN'=>'塞內加爾',
        'SO'=>'索馬利亞',
        'SR'=>'蘇利南',
        'ST'=>'聖多美和普林西比',
        'SU'=>'蘇維埃聯盟',
        'SV'=>'薩爾瓦多',
        'SY'=>'敘利亞阿拉伯共和國',
        'SZ'=>'史瓦濟蘭',
        'TC'=>'特克斯和凱科斯群島',
        'TD'=>'查德',
        'TF'=>'法屬南部領地',
        'TG'=>'多哥',
        'TH'=>'泰國',
        'TJ'=>'塔吉克',
        'TK'=>'托克勞群島',
        'TI'=>'東帝汶',
        'TM'=>'土庫曼',
        'TN'=>'突尼西亞',
        'TO'=>'湯加',
        'TP'=>'東帝汶 (舊碼)',
        'TR'=>'土耳其',
        'TT'=>'特立尼達和多巴哥',
        'TV'=>'吐瓦魯',
        'TW'=>'台灣',
        'TZ'=>'坦尚尼亞',
        'UA'=>'烏克蘭',
        'UG'=>'烏干達',
        'UK'=>'英國',
        'US'=>'美國',
        'UM'=>'美國本土外小島嶼',
        'UY'=>'烏拉圭',
        'UZ'=>'烏茲別克',
        'VA'=>'梵蒂岡城國 (聖座)',
        'VC'=>'聖文森特和格林納丁斯',
        'VE'=>'委內瑞拉',
        'VG'=>'英屬維京群島',
        'VI'=>'美屬維京群島',
        'VN'=>'越南',
        'VU'=>'萬那杜',
        'WF'=>'瓦利斯和富圖納群島',
        'WS'=>'薩摩亞',
        'YE'=>'葉門',
        'YT'=>'馬約特',
        'ZA'=>'南非',
        'ZM'=>'尚比亞',
        'ZW'=>'辛巴威',
    ],
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/zh-TW/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> '美式英語',
        'en-GB'=> '英式英語',
        'am-ET' => 'Amharic',
        'af-ZA'=> '南非荷蘭語',
        'ar-SA'=> '阿拉伯語',
        'bg-BG'=> '保加利亞語',
        'zh-CN'=> '簡體中文',
        'zh-TW'=> '繁體中文',
        'ca-ES' => 'Catalan',
        'hr-HR'=> '克羅埃西亞語',
        'cs-CZ'=> '捷克語',
        'da-DK'=> '丹麥語',
        'nl-NL'=> '荷蘭語',
        'en-ID'=> '印度尼西亞英語',
        'et-EE'=> '愛沙尼亞語',
        'fil-PH'=> '菲律賓語',
        'fi-FI'=> '芬蘭語',
        'fr-FR'=> '法語',
        'de-DE'=> '德語',
        'de-if'=> '德語（非正式）',
        'el-GR'=> '希臘語',
        'he-IL'=> '希伯來語',
        'hu-HU'=> '匈牙利語',
        'is-IS' => '冰島語',
        'id-ID'=> '印尼語',
        'ga-IE'=> '愛爾蘭語',
        'it-IT'=> '義大利語',
        'ja-JP'=> '日語',
        'km-KH'=>'Khmer',
        'ko-KR'=> '韓語',
        'lt-LT'=>'立陶宛語',
        'lv-LV'=> '拉脫維亞語',
        'mk-MK'=> '馬其頓語',
        'ms-MY'=> '馬來語',
        'mi-NZ'=> '毛利語',
        'mn-MN'=> '蒙古語',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> '波斯語',
        'pl-PL'=> '波蘭語',
        'pt-PT'=> '葡萄牙語',
        'pt-BR'=> '巴西葡萄牙語',
        'ro-RO'=> '羅馬尼亞語',
        'ru-RU'=> '俄語',
        'sr-CS' => '塞爾維亞語（拉丁文）',
        'sk-SK'=> 'Slovak',
        'sl-SI'=> '斯洛維尼亞語',
        'so-SO'=> 'Somali',
        'es-ES'=> '西班牙語',
        'es-CO'=> '哥倫比亞西班牙語',
        'es-MX'=> '墨西哥西班牙語',
        'es-VE'=> '委內瑞拉西班牙語',
        'sv-SE'=> '瑞典語',
        'tl-PH'=> '塔加洛語',
        'ta-IN'=> '泰米爾語',
        'th-TH'=> '泰語',
        'tr-TR'=> '土耳其語',
        'uk-UA'=> '烏克蘭語',
        'vi-VN'=> '越南語',
        'cy-GB'=> '威爾斯語',
        'zu-ZA'=> '祖魯語',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'阿森松島',
        'AD'=>'安道爾',
        'AE'=>'阿拉伯聯合大公國',
        'AF'=>'阿富汗',
        'AG'=>'安提瓜和巴布達',
        'AI'=>'安圭拉',
        'AL'=>'阿爾巴尼亞',
        'AM'=>'亞美尼亞',
        'AN'=>'荷屬安的列斯',
        'AO'=>'安哥拉',
        'AQ'=>'南極洲',
        'AR'=>'阿根廷',
        'AS'=>'美屬薩摩亞',
        'AT'=>'奧地利',
        'AU'=>'澳洲',
        'AW'=>'阿魯巴',
        'AX'=>'奧蘭群島',
        'AZ'=>'亞塞拜然',
        'BA'=>'波士尼亞和赫塞哥維納',
        'BB'=>'巴貝多',
        'BE'=>'比利時',
        'BD'=>'孟加拉',
        'BF'=>'布吉納法索',
        'BG'=>'保加利亞',
        'BH'=>'巴林',
        'BI'=>'蒲隆地',
        'BJ'=>'貝南',
        'BM'=>'百慕達',
        'BN'=>'汶萊',
        'BO'=>'玻利維亞',
        'BR'=>'巴西',
        'BS'=>'巴哈馬',
        'BT'=>'不丹',
        'BV'=>'布韋島',
        'BW'=>'波札那',
        'BY'=>'白俄羅斯',
        'BZ'=>'貝里斯',
        'CA'=>'加拿大',
        'CC'=>'科科斯（基林）群島',
        'CD'=>'剛果（金夏沙）',
        'CF'=>'中非共和國',
        'CG'=>'剛果（布拉薩）',
        'CH'=>'瑞士',
        'CI'=>'象牙海岸',
        'CK'=>'庫克群島',
        'CL'=>'智利',
        'CM'=>'喀麥隆',
        'CN'=>'中華人民共和國',
        'CO'=>'哥倫比亞',
        'CR'=>'哥斯大黎加',
        'CU'=>'古巴',
        'CV'=>'維德角',
        'CX'=>'聖誕島',
        'CY'=>'賽普勒斯',
        'CZ'=>'捷克',
        'DE'=>'德國',
        'DJ'=>'吉布地',
        'DK'=>'丹麥',
        'DM'=>'多米尼克',
        'DO'=>'多明尼加共和國',
        'DZ'=>'阿爾及利亞',
        'EC'=>'厄瓜多',
        'EE'=>'愛沙尼亞',
        'EG'=>'埃及',
        'GB-ENG'=>'England',
        'ER'=>'厄利垂亞',
        'ES'=>'西班牙',
        'ET'=>'衣索比亞',
        'EU'=>'歐洲聯盟',
        'FI'=>'芬蘭',
        'FJ'=>'斐濟',
        'FK'=>'福克蘭群島',
        'FM'=>'密克羅尼西亞聯邦',
        'FO'=>'法羅群島',
        'FR'=>'法國',
        'GA'=>'加彭',
        'GD'=>'格瑞那達',
        'GE'=>'喬治亞',
        'GF'=>'法屬圭亞那',
        'GG'=>'根西島',
        'GH'=>'迦納',
        'GI'=>'直布羅陀',
        'GL'=>'格陵蘭',
        'GM'=>'甘比亞',
        'GN'=>'幾內亞',
        'GP'=>'瓜地洛普',
        'GQ'=>'赤道幾內亞',
        'GR'=>'希臘',
        'GS'=>'南喬治亞與南桑威奇群島',
        'GT'=>'瓜地馬拉',
        'GU'=>'關島',
        'GW'=>'幾內亞比索',
        'GY'=>'蓋亞那',
        'HK'=>'香港',
        'HM'=>'赫德島和麥當勞群島',
        'HN'=>'洪都拉斯',
        'HR'=>'克羅埃西亞',
        'HT'=>'海地',
        'HU'=>'匈牙利',
        'ID'=>'印尼',
        'IE'=>'愛爾蘭',
        'IL'=>'以色列',
        'IM'=>'曼島',
        'IN'=>'印度',
        'IO'=>'英屬印度洋領地',
        'IQ'=>'伊拉克',
        'IR'=>'伊朗',
        'IS'=>'冰島',
        'IT'=>'義大利',
        'JE'=>'澤西島',
        'JM'=>'牙買加',
        'JO'=>'約旦',
        'JP'=>'日本',
        'KE'=>'肯亞',
        'KG'=>'吉爾吉斯',
        'KH'=>'柬埔寨',
        'KI'=>'吉里巴斯',
        'KM'=>'葛摩',
        'KN'=>'聖克里斯多福和尼維斯',
        'KR'=>'南韓',
        'KW'=>'科威特',
        'KY'=>'開曼群島',
        'KZ'=>'哈薩克',
        'LA'=>'寮國',
        'LB'=>'黎巴嫩',
        'LC'=>'聖露西亞',
        'LI'=>'列支敦斯登',
        'LK'=>'斯里蘭卡',
        'LR'=>'賴比瑞亞',
        'LS'=>'賴索托',
        'LT'=>'立陶宛',
        'LU'=>'盧森堡',
        'LV'=>'拉脫維亞',
        'LY'=>'利比亞',
        'MA'=>'摩洛哥',
        'MC'=>'摩納哥',
        'MD'=>'摩爾多瓦',
        'ME'=>'蒙特內哥羅',
        'MG'=>'馬達加斯加',
        'MH'=>'馬紹爾群島',
        'MK'=>'馬其頓',
        'ML'=>'馬利',
        'MM'=>'緬甸',
        'MN'=>'蒙古',
        'MO'=>'澳門',
        'MP'=>'北馬里亞納群島',
        'MQ'=>'馬丁尼克',
        'MR'=>'茅利塔尼亞',
        'MS'=>'蒙特塞拉特',
        'MT'=>'馬爾他',
        'MU'=>'模里西斯',
        'MV'=>'馬爾地夫',
        'MW'=>'馬拉威',
        'MX'=>'墨西哥',
        'MY'=>'馬來西亞',
        'MZ'=>'莫三比克',
        'NA'=>'納米比亞',
        'NC'=>'新喀里多尼亞',
        'NE'=>'尼日',
        'NF'=>'諾福克島',
        'NG'=>'奈及利亞',
        'NI'=>'尼加拉瓜',
        'NL'=>'荷蘭',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'挪威',
        'NP'=>'尼泊爾',
        'NR'=>'諾魯',
        'NU'=>'紐埃',
        'NZ'=>'紐西蘭',
        'OM'=>'阿曼',
        'PA'=>'巴拿馬',
        'PE'=>'秘魯',
        'PF'=>'法屬玻里尼西亞',
        'PG'=>'巴布亞紐幾內亞',
        'PH'=>'菲律賓',
        'PK'=>'巴基斯坦',
        'PL'=>'波蘭',
        'PM'=>'聖皮耶與密克隆',
        'PN'=>'皮特肯群島',
        'PR'=>'波多黎各',
        'PS'=>'巴勒斯坦',
        'PT'=>'葡萄牙',
        'PW'=>'帛琉',
        'PY'=>'巴拉圭',
        'QA'=>'卡達',
        'RE'=>'留尼旺',
        'RO'=>'羅馬尼亞',
        'RS'=>'塞爾維亞',
        'RU'=>'俄羅斯',
        'RW'=>'盧安達',
        'SA'=>'沙烏地阿拉伯',
        'GB-SCT'=>'英國',
        'SB'=>'索羅門群島',
        'SC'=>'塞席爾',
        'SS'=>'南蘇丹',
        'SD'=>'蘇丹',
        'SE'=>'瑞典',
        'SG'=>'新加坡',
        'SH'=>'聖赫勒拿島',
        'SI'=>'斯洛維尼亞',
        'SJ'=>'斯瓦爾巴特和揚馬延島',
        'SK'=>'斯洛伐克',
        'SL'=>'獅子山',
        'SM'=>'聖馬利諾',
        'SN'=>'塞內加爾',
        'SO'=>'索馬利亞',
        'SR'=>'蘇利南',
        'ST'=>'聖多美和普林西比',
        'SU'=>'蘇維埃聯盟',
        'SV'=>'薩爾瓦多',
        'SY'=>'敘利亞阿拉伯共和國',
        'SZ'=>'史瓦濟蘭',
        'TC'=>'特克斯和凱科斯群島',
        'TD'=>'查德',
        'TF'=>'法屬南部領地',
        'TG'=>'多哥',
        'TH'=>'泰國',
        'TJ'=>'塔吉克',
        'TK'=>'托克勞群島',
        'TI'=>'東帝汶',
        'TM'=>'土庫曼',
        'TN'=>'突尼西亞',
        'TO'=>'湯加',
        'TP'=>'東帝汶 (舊碼)',
        'TR'=>'土耳其',
        'TT'=>'特立尼達和多巴哥',
        'TV'=>'吐瓦魯',
        'TW'=>'台灣',
        'TZ'=>'坦尚尼亞',
        'UA'=>'烏克蘭',
        'UG'=>'烏干達',
        'UK'=>'英國',
        'US'=>'美國',
        'UM'=>'美國本土外小島嶼',
        'UY'=>'烏拉圭',
        'UZ'=>'烏茲別克',
        'VA'=>'梵蒂岡城國 (聖座)',
        'VC'=>'聖文森特和格林納丁斯',
        'VE'=>'委內瑞拉',
        'VG'=>'英屬維京群島',
        'VI'=>'美屬維京群島',
        'VN'=>'越南',
        'VU'=>'萬那杜',
        'GB-WLS' =>'Wales',
        'WF'=>'瓦利斯和富圖納群島',
        'WS'=>'薩摩亞',
        'YE'=>'葉門',
        'YT'=>'馬約特',
        'ZA'=>'南非',
        'ZM'=>'尚比亞',
        'ZW'=>'辛巴威',
    ],
];
